@@ -3,7 +3,7 @@
  *  Definition of GiNaC's exprseq. */
 
 /*
- *  GiNaC Copyright (C) 1999-2017 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2022 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,6 +31,11 @@ namespace GiNaC {
 
 typedef container<std::vector> exprseq;
 
+/** Declaration of container::reg_info for exprseq. */
+#ifndef _MSC_VER  // workaround error C2766: explicit specialization; 'reg_info' has already been defined
+template<> registered_class_info exprseq::reg_info;
+#endif
+
 // defined in exprseq.cpp
 template<> bool exprseq::info(unsigned inf) const;
 
